cmoncrawl.common.types.PipeMetadata.__init__ — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.common.types.PipeMetadata.__init__

PipeMetadata.__init__(domain_record: ~cmoncrawl.common.types.DomainRecord, article_data: ~typing.Dict[~typing.Any, ~typing.Any] = <factory>, warc_header: ~typing.Dict[str, ~typing.Any] = <factory>, http_header: ~typing.Dict[str, ~typing.Any] = <factory>, encoding: str = 'latin-1', name: ~typing.Optional[str] = None) → None